Struct cli_table::CellStruct [−][src]
pub struct CellStruct { /* fields omitted */ }Concrete cell of a table
Implementations
impl CellStruct[src]
impl CellStruct[src]pub fn justify(self, justify: Justify) -> CellStruct[src]
Used to horizontally justify contents of a cell
pub fn align(self, align: Align) -> CellStruct[src]
Used to vertically align the contents of a cell
pub fn padding(self, padding: Padding) -> CellStruct[src]
Used to add padding to the contents of a cell